@@ -14,11 +14,11 @@ def load_okex():
     file_pro.change_data_type('trade')
     file_pro.change_timeframe('detail')
     file_pro.change_freq('daily')
-    file_pro.load(total=450)
-    file_pro.change_freq('weekly')
-    file_pro.load(total=60)
-    file_pro.change_freq('monthly')
-    file_pro.load(total=12)
+    file_pro.load(total=1)
+    # file_pro.change_freq('weekly')
+    # file_pro.load(total=60)
+    # file_pro.change_freq('monthly')
+    # file_pro.load(total=12)
 
     file_pro.change_data_type('kline')
     file_pro.change_timeframe('1m')
